fn set_all_mtimes_to_epoch(fs: &mut FileSystem<Sha256HashValue>)Expand description
Set all modification times in the filesystem to Unix epoch (0).
fn set_all_mtimes_to_epoch(fs: &mut FileSystem<Sha256HashValue>)Set all modification times in the filesystem to Unix epoch (0).