struct Args {Show 14 fields
from_file: bool,
print_digest: bool,
print_digest_only: bool,
use_epoch: bool,
skip_devices: bool,
skip_xattrs: bool,
user_xattrs: bool,
min_version: u32,
max_version: u32,
digest_store: Option<PathBuf>,
hardlinks: bool,
threads: Option<usize>,
source: PathBuf,
image: Option<PathBuf>,
}Expand description
Create a composefs image from a source directory or dumpfile.
Composefs uses EROFS image files for metadata and separate content-addressed backing directories for regular file data.
Fields
from_file: boolTreat SOURCE as a dumpfile in composefs-dump(5) format.
If SOURCE is -, reads from stdin.
print_digest: boolPrint the fsverity digest of the image after writing.
print_digest_only: boolPrint the fsverity digest without writing the image.
When set, IMAGE must be omitted.
use_epoch: boolSet modification time to zero (Unix epoch) for all files.
skip_devices: boolExclude device nodes from the image.
skip_xattrs: boolExclude all extended attributes.
user_xattrs: boolOnly include xattrs with the user. prefix.
min_version: u32Minimum image format version to use (0 or 1).
max_version: u32Maximum image format version (for auto-upgrade).
digest_store: Option<PathBuf>Copy regular file content to the given object store directory.
Files are stored by their fsverity digest using the same flat layout
as C mkcomposefs: XX/DIGEST where XX is the first byte of the digest.
The directory is created if it doesn’t exist. The layout is compatible
with digest stores written by the C mkcomposefs tool.
hardlinks: boolDeduplicate hard-linked files on the source filesystem into shared EROFS inodes. Without this flag the output is bit-for-bit compatible with the C mkcomposefs tool.
threads: Option<usize>Number of threads to use for digest calculation and file copying.
source: PathBufThe source directory or dumpfile.
image: Option<PathBuf>The output image path (use - for stdout).
Must be omitted when using –print-digest-only.